@@ -4,6 +4,7 @@ from .tokenization import Tokenization, AsyncTokenization
 from .classification import Classification, AsyncClassification
 from .bot import BotChat, AsyncBotChat
 from .context import Context, AsyncContext
+from .multimodal_embeddings import MultimodalEmbeddings, AsyncMultimodalEmbeddings
 from .content_generation import ContentGeneration, AsyncContentGeneration
 from .batch_chat import BatchChat, AsyncBatchChat
 
@@ -18,8 +19,11 @@ __all__ = [
     "AsyncTokenization",
     "Context",
     "AsyncContext",
+    "MultimodalEmbeddings",
+    "AsyncMultimodalEmbeddings",
+    "AsyncContext",
     "ContentGeneration",
-    "AsyncContentGeneration"
+    "AsyncContentGeneration",
     "BatchChat",
     "AsyncBatchChat"
 ]
